package sun.text;

import java.text.CharacterIterator;

final class CharacterIteratorCodePointIterator extends CodePointIterator
{
    private CharacterIterator iter;
    
    public CharacterIteratorCodePointIterator(CharacterIterator iter) {
        this.iter = iter;
    }
    
    @Override
    public void setToStart() {
        this.iter.setIndex(this.iter.getBeginIndex());
    }
    
    @Override
    public void setToLimit() {
        this.iter.setIndex(this.iter.getEndIndex());
    }
    
    @Override
    public int next() {
        int current = this.iter.current();
        if (current != '\uffff') {
            int next = this.iter.next();
            if (Character.isHighSurrogate((char)current) && next != '\uffff' && Character.isLowSurrogate((char)next)) {
                this.iter.next();
                return Character.toCodePoint((char)current, (char)next);
            }
            return current;
        }
        else {
            return -1;
        }
    }
    
    @Override
    public int prev() {
        int previous = this.iter.previous();
        if (previous != '\uffff') {
            if (Character.isLowSurrogate((char)previous)) {
                int previous2 = this.iter.previous();
                if (Character.isHighSurrogate((char)previous2)) {
                    return Character.toCodePoint((char)previous2, (char)previous);
                }
                this.iter.next();
            }
            return previous;
        }
        else {
            return -1;
        }
    }
    
    @Override
    public int charIndex() {
        return this.iter.getIndex();
    }
}
